@@ -14,5 +14,4 @@
 # Make this a package.
 from grokcore.startup.startup import (application_factory,
                                       debug_application_factory,
-                                      interactive_debug_prompt,
-                                      zdaemon_controller)
+                                      interactive_debug_prompt)
